California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 64 - LIMITATIONS ON ENFORCEMENT OF UNFAIR BUSINESS COMPETITION LAWS. INITIATIVE STATUTE View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270479 | PUBLIC HEALTH WARNING: NO ON 64, A COALITION OF ENVIRONMENTAL, PUBLIC HEALTH AND CONSUMER GROUPS, REGISTERED NURSES, AND ENVIRONMENTAL AND CONSUMER ATTORNEYS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256259 | CALIFORNIA MOTOR CAR DEALERS ASSOCIATION FUND TO STOP SHAKEDOWN LAWSUITS - YES ON 64 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257254 | YES ON 64 -- CALIFORNIANS TO STOP SHAKEDOWN LAWSUITS, A COALITION OF TAXPAYERS, AUTOMOBILE DEALERS, BUSINESS GROUPS AND CIVIL JUSTICE REFORM SUPPORTERS | SUPPORT